<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://fncd.net
 * @since      1.0.0
 *
 * @package    Final_Countdown
 * @subpackage Final_Countdown/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Final_Countdown
 * @subpackage Final_Countdown/admin
 * @author     Final Countdown <fncd@thangbom.us>
 */
class Final_Countdown_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Final_Countdown_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Final_Countdown_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		
		/* load WP colorpicker */
		wp_enqueue_style( 'wp-color-picker' );
		
	
		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/final-countdown-admin.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Final_Countdown_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Final_Countdown_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		add_thickbox();
		
		/* load jQuery-ui slider */
		wp_enqueue_script( 'jquery-ui-slider' );
		
		/* load jQuery-ui datepicker */
		wp_enqueue_script( 'jquery-ui-datepicker' );
		
		/* load WP colorpicker */
		wp_enqueue_script( 'wp-color-picker' );
		
		/* load jQuery UI timepicker addon */
		wp_enqueue_script( 'jquery-ui-timepicker', plugin_dir_url( __FILE__ ) . 'js/jquery-ui-timepicker-addon.min.js', array( 'jquery', 'jquery-ui-slider', 'jquery-ui-datepicker' ) );
		
		//wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/final-countdown-admin.js', array( 'jquery' ), $this->version, false );

	}
	
	/**
	 * Register Countdown Button for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function countdown_button() {
	
		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Final_Countdown_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Final_Countdown_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
	
		$img =  plugin_dir_url( __FILE__ ) . 'images/countdown_logo.png';
		$context="";
		$title = 'Add Final Countdown';	
		$context .= '<a class="button thickbox" title="Create Final Countdown and insert in posts/pages"    href="'.admin_url("admin-ajax.php").'?action=final_countdown_window_manager&height=750&width=640">
		<span class="wp-media-buttons-icon" style="background: url('.$img.'); background-repeat: no-repeat; background-position: left bottom;"></span>
		Add Final Countdown
		</a>';  
		return $context;
	
	}
	
	
	/**
	 * Countdown Button window/popup content for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function final_countdown_window_insert_content() {
	
		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Final_Countdown_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Final_Countdown_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		
		$timezone_identifiers = DateTimeZone::listIdentifiers();
		
	?>
		<style>
	 
		#final_countdown_window_manager > tbody > tr:nth-child(odd) {
		  background-color: rgba(176, 176, 176, 0.07);
		}
		#final_countdown_window_manager>tfoot>tr>td{
			border-top:1px solid #ccc;
		}
		#final_countdown_window_manager>tbody>tr>td:first-child{
			width:30%;
		}
		#TB_window{  
			overflow-y: auto;
		}
		#TB_ajaxContent{
			width:95% !important;
		}
		.wp-picker-holder{
			position: absolute;
			z-index: 100000;
		}
		.desription_class{
			float: right;
			cursor: default;
			color: #0074a2;
			font-size: 18px;
			font-weight: bold;
			border: 1px solid #000000;
			border-radius: 200px;
			height: 20px;
			padding-left: 6px;
			padding-right: 6px;
			margin-left: 15px;
		}
		.final_countdown_spinner{float: left;}	
		.final_countdown_pro_link{font-size: 20px;line-height: normal;}
		.final_countdown_recopt{width: 100%; float: left;  margin-bottom: 10px;}
		.final_countdown_frequency_block,.final_countdown_recrepton_block,.final_countdown_interval_block,.final_countdown_endson_block{display: none;}
		</style>
		<table id="final_countdown_window_manager" class="wp-list-table widefat fixed posts section_parametrs_table">  
                <tbody>
               		<tr>
						<td>
							Event Name <span title="This is the name of the Event you are counting down to." class="desription_class">?</span>
						</td>
						<td>
							<input type="text" name="final_countdown_event_name"  id="final_countdown_event_name" value="">
						</td>                
					</tr>
                	<tr>
						<td>
							Date <span title="This is the date of the Event." class="desription_class">?</span>
						</td>
						<td>
							<input type="text" name="final_countdown_date"  id="final_countdown_date" value="" readonly>
						</td>                
					</tr>
                    <tr>
						<td>
							Time <span title="This is the time of the Event." class="desription_class">?</span>
						</td>
						<td>
							<input type="text" name="final_countdown_time"  id="final_countdown_time" value="" readonly>
						</td>                
					</tr>
                    <tr>
						<td>
							Timezone  <span title="This is the timezone of the event." class="desription_class">?</span>
						</td>
						<td>
							<select id="final_countdown_timezone" name="final_countdown_timezone" >
                              <?php 
                              	foreach ($timezone_identifiers as $key=>$value)
                              	{
                              		?>
                              		<option value="<?php echo $value;?>"><?php echo $value;?></option>
                              		<?php 
                              	}
                              ?>
                        	</select>
                         </td>             
					</tr>
					<tr>
						<td>
							Recurring <span title="Check this box if you want start recurring." class="desription_class">?</span>
						</td>
						<td>
							<input type="checkbox" name="final_countdown_recurring"  id="final_countdown_recurring" value="true">
						</td>                
					</tr>
					<tr class="final_countdown_frequency_block">
						<td>
							Frequency  <span title="Recurring Frequency." class="desription_class">?</span>
						</td>
						<td>
							<select id="final_countdown_rfrequency" name="final_countdown_rfrequency" >
								<option value="MINUTELY">Minutely</option>
								<option value="HOURLY">Hourly</option>
								<option value="DAILY">Daily</option>
                            	<option value="WEEKLY">Weekly</option>
                            	<option value="YEARLY">Yearly</option>
                        	</select>
                         </td>             
					</tr>
					<tr class="final_countdown_recrepton_block">
						<td>Repeat on <span title="Check week days" class="desription_class">?</span></td>
						<td>
							<div>
								<span class="final_countdown_recrepton"><input id="final_countdown_rrepton_mo" name="final_countdown_rrepton" type="checkbox" aria-label="Repeat on Monday" value="MO"><label for="final_countdown_rrepton_mo" title="Monday">MO</label></span>
								<span class="final_countdown_recrepton"><input id="final_countdown_rrepton_tu" name="final_countdown_rrepton" type="checkbox" aria-label="Repeat on Tuesday" value="TU"><label for="final_countdown_rrepton_tu" title="Tuesday">TU</label></span>
								<span class="final_countdown_recrepton"><input id="final_countdown_rrepton_we" name="final_countdown_rrepton" type="checkbox" aria-label="Repeat on Wednesday" value="WE"><label for="final_countdown_rrepton_we" title="Wednesday">WE</label></span>
								<span class="final_countdown_recrepton"><input id="final_countdown_rrepton_th" name="final_countdown_rrepton" type="checkbox" aria-label="Repeat on Thursday" value="TH"><label for="final_countdown_rrepton_th" title="Thursday">TH</label></span>
								<span class="final_countdown_recrepton"><input id="final_countdown_rrepton_fr" name="final_countdown_rrepton" type="checkbox"  aria-label="Repeat on Friday" value="FR"><label for="final_countdown_rrepton_fr" title="Friday">FR</label></span>
								<span class="final_countdown_recrepton"><input id="final_countdown_rrepton_sa" name="final_countdown_rrepton" type="checkbox" aria-label="Repeat on Saturday" value="SA"><label for="final_countdown_rrepton_sa" title="Saturday">SA</label></span>
								<span class="final_countdown_recrepton"><input id="final_countdown_rrepton_su" name="final_countdown_rrepton" type="checkbox" aria-label="Repeat on Sunday" value="SU"><label for="final_countdown_rrepton_su" title="Sunday">SU</label></span>
							</div>
						</td>
					</tr>
					<tr class="final_countdown_interval_block">
						<td>
							Repeat Every  <span title="Recurring Interval." class="desription_class">?</span>
						</td>
						<td>
							<select id="final_countdown_rinterval" name="final_countdown_rinterval" >
								<?php 
                              	for($interval=1;$interval<=99;$interval++)
                              	{
                              		?>
                              		<option value="<?php echo $interval;?>"><?php echo $interval;?></option>
                              		<?php 
                              	}
                              	?>
                        	</select>
                        	<label id="final_countdown_rinterval_label">Minutes</label>
                         </td>             
					</tr>
					<tr class="final_countdown_endson_block">
						<td>
							Ends On  <span title="Recurring Ends On" class="desription_class">?</span>
						</td>
						<td>
							<span class="final_countdown_recopt">
								<input id="final_countdown_recopt_never" name="final_countdown_endson" type="radio" checked="checked" aria-label="Ends never" title="Ends never" value="never">
								<label for="final_countdown_recopt_never" title="Ends never">Never</label>
							</span>
							<span class="final_countdown_recopt">
								<input id="final_countdown_recopt_count" name="final_countdown_endson" type="radio" aria-label="Ends after a number of occurrences" title="Ends after a number of occurrences" value="count">
								<label for="final_countdown_recopt_count" title="Ends after a number of occurrences">After <input type="number"  id="final_countdown_count_input" size="3" value="" title="Occurrences" disabled="disabled" min="1"> occurrences</label>
							</span>
							<span class="final_countdown_recopt">
								<input id="final_countdown_recopt_until" name="final_countdown_endson" type="radio" aria-label="Ends on a specified date" title="Ends on a specified date" value="until">
								<label for="final_countdown_recopt_until" title="Ends on a specified date">On <input id="final_countdown_until_input" value="" title="Specified date" autocomplete="off" readonly="readonly"></label>
							</span>
                         </td>             
					</tr>
					<tr>
						<td>
							Count up <span title="Check this box if you want the Countdown to count up to display the time since the Event expired." class="desription_class">?</span>
						</td>
						<td>
							<input type="checkbox" name="final_countdown_countup"  id="final_countdown_countup" value="true">
						</td>                
					</tr>
					<tr>
						<td>
							Font Style <span title="This is font style of text." class="desription_class">?</span>
						</td>
					 	
                        <td style="vertical-align: top !important;">
                            <div style="margin-right:3px; width:25%;float:left;">
                            	<select id="final_countdown_font" name="final_countdown_font">
	                                <option selected="selected" value="0">Style 1</option>
	                                <option value="1">Style 2</option>
	                                <option value="2">Style 3</option>
	                                <option value="3">Style 4</option>
	                                <option value="4">Style 5</option>
	                                <option value="5">Style 6</option>
	                        	</select>
                            </div>
                           	<div style="width:70%;float:left">
                              <!-- <img alt="" src="<?php echo plugin_dir_url( __FILE__ ) . 'images/Font0.png';?>" style="width:100%;height:auto;" id="final_countdown_font_img"> -->   
                                 <iframe src="//fncd.net/embed?id=wt3jxdI"" style="width:100%;height:150px;" id="final_countdown_preview" ></iframe>
                            </div>
                         </td>       
                                       
					</tr>
					<tr>
						<td>
							Title Color <span title="The color of the Event name text." class="desription_class">?</span>
						</td>
						<td>
							<input type="text" name="final_countdown_title_color"  id="final_countdown_title_color"  value="#ffffff">
						</td>                
					</tr>
					<tr>
						<td>
							Border Color <span title="The color of the Border" class="desription_class">?</span>
						</td>
						<td>
							<input type="text" name="final_countdown_border_color"  id="final_countdown_border_color" value="#000000">
						</td>                
					</tr>
					<tr>
						<td>
							Background Color <span title="The color of the Background." class="desription_class">?</span>
						</td>
						<td>
							<input type="text" name="final_countdown_background_color"  id="final_countdown_background_color" value="#000000">
						</td>                
					</tr>
					<tr>
						<td>
							Background Opacity<span title="The Background Color Opacity." class="desription_class">?</span>
						</td>
						<td>
							<input type="hidden" name="final_countdown_background_opacity"  id="final_countdown_background_opacity" value="0" >
							<div class="ui-opacitypicker-div">
								<div id="final_countdown_slider" style="float: left;width: 210px;"></div>
								<div id="final_countdown_slider_val"  style="float: left;margin-left: 10px;"></label>
							</div>
							
						</td>                
					</tr>
					<tr>
						<td>
							Width <span title="Width of Countdown block." class="desription_class">?</span>
						</td>
						<td> 
							<input type="text" name="final_countdown_width"  id="final_countdown_width" value="300px"> (Ex. 100px or 100%)
						</td>                
					</tr>
					<tr>
						<td>
							Height <span title="Height of Countdown block." class="desription_class">?</span>
						</td>
						<td>
							<input type="text" name="final_countdown_height"  id="final_countdown_height" value="150px"> (Ex. 100px or 100%)
						</td>                
					</tr>
                </tbody>
                 <tfoot>
                	<tr>  
                        <td colspan="2">
                        	 <div style="display:inline-block; float:right" ><a href="https://www.fncd.net/pricing.html" target="_blank" class="final_countdown_pro_link">Upgrade to Pro version - Ad free</a></div>
                        	 
                        </td>                
                    </tr>
                    <tr>  
                        <td colspan="2">
                        	 <div style="display:inline-block; float:right;" ><span class="final_countdown_spinner spinner">&nbsp;</span><input type="button" id="insert_final_countdown" name="insert_final_countdown" value="Insert Final Countdown" class="button button-primary" onClick="insert_final_countdown();"/></div>
                        </td>                
                    </tr>
                </tfoot>
            </table>    
            <script>
          
        	jQuery('#final_countdown_window_manager').ready(function(e) {
        		jQuery('#TB_window').css('max-height',(jQuery('#final_countdown_window_manager').height()+135)+'px');
             	jQuery('#TB_ajaxContent').css('max-height',(jQuery('#final_countdown_window_manager').height()+26)+'px');
        		jQuery("#final_countdown_title_color,#final_countdown_background_color,#final_countdown_border_color").wpColorPicker({defaultColor:'#ffffff',change:function(event, ui){
        			event.preventDefault();
        			generatePreviewString();
            	}});
        		jQuery('#final_countdown_date').datepicker({
        			   showOtherMonths: true,
        		       showButtonPanel: true,
        		       defaultDate:0,
        		       minDate:0,
        		       dateFormat: 'dd/mm/yy',
        		       onSelect: function(dateText) {
        		    	   generatePreviewString();
        		       }
        	      });
        		jQuery("#final_countdown_date").datepicker("setDate", new Date());
        		jQuery('#final_countdown_time').timepicker({
        			onSelect: function(dateText) {
     		    	   generatePreviewString();
     		       }
  		        });
        		jQuery("#final_countdown_time").datepicker("setDate", new Date());


        		/*jQuery('#final_countdown_font').on('change',function(){
					jQuery("#final_countdown_font_img").attr('src',"<?php //echo plugin_dir_url( __FILE__ ) . 'images/';?>"+"Font"+jQuery('#final_countdown_font').val()+".png");
        		});*/


        		jQuery( "#final_countdown_slider" ).slider({
        		      value:1,
        		      min: 0,
        		      max: 1,
        		      step: 0.01,
        		      slide: function( event, ui ) {
        		    	  jQuery( "#final_countdown_background_opacity" ).val(ui.value);
        		    	  jQuery( "#final_countdown_slider_val" ).html (ui.value);
        		    	  generatePreviewString();
        		      }
        		    });
        		jQuery( "#final_countdown_background_opacity" ).val( jQuery( "#final_countdown_slider" ).slider( "value" ) );
        		jQuery( "#final_countdown_slider_val" ).html (jQuery( "#final_countdown_slider" ).slider( "value" ));

        		generatePreviewString();

        		jQuery("#final_countdown_timezone,#final_countdown_font,#final_countdown_countup").on('change',function(){
        			generatePreviewString();
            	})
            	jQuery("#final_countdown_event_name").on('blur',function(){
        			generatePreviewString();
            	})
            	
            	/* Recurring JS start */
            	
            	
            	jQuery("#final_countdown_recurring").on('click',function(){
            		 if (jQuery(this).is(':checked')) {
            			 jQuery(".final_countdown_frequency_block,.final_countdown_interval_block,.final_countdown_endson_block").show();
            			 jQuery("#final_countdown_rfrequency").prop("selectedIndex", 0);
            			 jQuery(".final_countdown_recrepton_block").hide();
            	     }
            		 else
            		 {
            			 jQuery(".final_countdown_frequency_block,.final_countdown_interval_block,.final_countdown_endson_block,.final_countdown_recrepton_block").hide();
            		 }
                })
                
                jQuery("#final_countdown_rfrequency").on('change',function(){
	           		switch(jQuery(this).val()) {
			           	case "MINUTELY":
			           	    jQuery("#final_countdown_rinterval_label").html('Minutes');
			           	 	jQuery(".final_countdown_recrepton_block").hide();
			           	    break;
			           	case "HOURLY":
			           		jQuery("#final_countdown_rinterval_label").html('Hours');
			           		jQuery(".final_countdown_recrepton_block").hide();
		           	        break;
			           	case "DAILY":
			           		jQuery("#final_countdown_rinterval_label").html('Days');
			           		jQuery(".final_countdown_recrepton_block").hide();
		           	        break;
			           	case "WEEKLY":
			           		jQuery("#final_countdown_rinterval_label").html('Weeks');
			           		jQuery(".final_countdown_recrepton_block").show();
		           	        break;		           	        		           				           	        
		           	    case "YEARLY":
		           	    	jQuery("#final_countdown_rinterval_label").html('Years');
		           	    	jQuery(".final_countdown_recrepton_block").hide();
		           	        break;
		           	    default:
		           	    	jQuery(".final_countdown_recrepton_block").hide();
	           		}
               })
               
               jQuery("input[name=final_countdown_endson]").on('click',function(){
            		 if (jQuery(this).is(':checked') && jQuery(this).val()=="count") {
            			jQuery('#final_countdown_count_input').val(5);
            			jQuery('#final_countdown_count_input').attr('disabled',false);
            	     }
            		 else
            		 {
            			 jQuery('#final_countdown_count_input').attr('disabled','disabled');
            		 }
                })

                jQuery('#final_countdown_until_input').datepicker({
     			   showOtherMonths: true,
     		       showButtonPanel: true,
     		       defaultDate:0,
     		       minDate:0,
     		       dateFormat: 'dd/mm/yy',
     	      	});

        		var untildate = new Date();
        		untildate.setDate(untildate.getDate() + 35);
     			jQuery("#final_countdown_until_input").datepicker("setDate", untildate);
            	
            	/* Recurring JS end */
            
        	});

        	function generatePreviewString()
        	{
                var tagtext;
				var event_name="";
				var event_date="";
				var event_time="";
				var timezone="";
				var count_up="false";
				var font_style="0";
				var title_color="-1";
				var border_color="-1";
				var backgroound_color="-1";
								
				if(jQuery('#final_countdown_event_name').length)
					event_name=jQuery.trim(jQuery('#final_countdown_event_name').val());
					
				if(jQuery('#final_countdown_date').length)
					event_date=jQuery('#final_countdown_date').val();
					
				if(jQuery('#final_countdown_time').length)
					event_time=jQuery('#final_countdown_time').val();
					
				if(jQuery('#final_countdown_timezone').length)
					timezone=jQuery('#final_countdown_timezone').val();
				
				if(jQuery('#final_countdown_countup').length)
					count_up=(jQuery('#final_countdown_countup').val()=="true")?"true":"false";
					
				if(jQuery('#final_countdown_font').length)
					font_style=jQuery('#final_countdown_font').val();
				
				if(jQuery('#final_countdown_title_color').length)
				{
					title_color="ff"+(jQuery('#final_countdown_title_color').val().substr(1));
					title_color=signedIntBin2Dec(hex2bin(title_color.toUpperCase()), 30)+"";
					
				}
				if(jQuery('#final_countdown_border_color').length)
				{
					border_color="ff"+(jQuery('#final_countdown_border_color').val().substr(1));
					border_color=signedIntBin2Dec(hex2bin(border_color.toUpperCase()), 30)+"";
					
				}		
				if(jQuery('#final_countdown_background_color').length)
				{
					
					background_opacity =percentageToHex(jQuery( "#final_countdown_background_opacity" ).val())
					backgroound_color=background_opacity+(jQuery('#final_countdown_background_color').val().substr(1));
					backgroound_color=signedIntBin2Dec(hex2bin(backgroound_color.toUpperCase()), 30)+"";
				}

				if(event_name=="")
				{
					event_name="Event Name";
				}

				
				var event_date_arr=event_date.split("/");
				var event_time_arr=event_time.split(":");
				var target_time=new Date(event_date_arr[2],(event_date_arr[1]-1),event_date_arr[0],event_time_arr[0],event_time_arr[1],0,0).getTime();
				
				var url = "https://fncd.net/embed-preview?name="+event_name+"&targetTime="+target_time+"&timezone="+timezone+"&countUp="+count_up+"&font="+font_style+"&color="+title_color+"&bgColor="+backgroound_color+"&titleColor="+title_color+"&borderColor="+border_color;

				jQuery("#final_countdown_preview").attr("src",url);
				
        	}

        	function hex2bin(hexNumber)
        	{
        		var hexaString = "0123456789ABCDEF";
        		var binaryArray = new Array ("0000","0001","0010","0011","0100","0101","0110","0111","1000","1001","1010","1011","1100","1101","1110","1111");
        		var binaryString;
        		binaryString = "";
        		for (var index = 0; index < hexNumber.length; index++)
        		{
        			binaryString += binaryArray[hexaString.indexOf(hexNumber.charAt(index))];
        		}
        		return binaryString;
        	}

        	function fastBin2Dec(binString)
        	{
        		var decNumber;
        		decNumber = 0;
        		for (var index = 0; index < binString.length; index++)
        		{
        			if (binString.charAt(index) == "1")
        			{
        				decNumber += Math.pow(2,binString.length-index-1);
        			}
        		}
        		return decNumber;
        	}
        	        	
        	function signedIntBin2Dec(expression)
        	{
        		var value;
        		value = fastBin2Dec(expression);
        		value =	integerFitRange(value, 0, 4294967295);
        		if (value > 2147483647)
        		{
        			value -= 4294967296;
        		}
        		return value;
        	}

        	function integerFitRange(value, min, max)
        	{
        		var temp;
        		temp = parseInt(Math.floor(value)+"");
        		if (temp<min)
        		{
        			temp = min;
        		}
        		if (temp>max)
        		{
        			temp = max;
        		}
        		return temp;
        	}

			function percentageToHex(percentage)
			{
				i = percentage;
				var alpha = Math.round(i * 255);
				var hex = alpha.toString(16);
				if (hex.length == 1) hex = "0" + hex;
				return hex;
				
			}
    	     	        	
            function insert_final_countdown() {          

                var tagtext;
				var event_name="";
				var event_date="";
				var event_time="";
				var timezone="";
				var count_up="false";
				var font_style="0";
				var title_color="-1";
				var border_color="-1";
				var backgroound_color="-1";
				var width="";
				var height="";

				if(jQuery('#final_countdown_event_name').length)
					event_name=jQuery.trim(jQuery('#final_countdown_event_name').val());
					
				if(jQuery('#final_countdown_date').length)
					event_date=jQuery('#final_countdown_date').val();
					
				if(jQuery('#final_countdown_time').length)
					event_time=jQuery('#final_countdown_time').val();
					
				if(jQuery('#final_countdown_timezone').length)
					timezone=jQuery('#final_countdown_timezone').val();
				
				if(jQuery('#final_countdown_countup').length)
					count_up=(jQuery('#final_countdown_countup').val()=="true")?"true":"false";
					
				if(jQuery('#final_countdown_font').length)
					font_style=jQuery('#final_countdown_font').val();
				
				if(jQuery('#final_countdown_title_color').length)
				{
					title_color="ff"+(jQuery('#final_countdown_title_color').val().substr(1));
					title_color=signedIntBin2Dec(hex2bin(title_color.toUpperCase()), 30)+"";
					
				}
				if(jQuery('#final_countdown_border_color').length)
				{
					border_color="ff"+(jQuery('#final_countdown_border_color').val().substr(1));
					border_color=signedIntBin2Dec(hex2bin(border_color.toUpperCase()), 30)+"";
					
				}		
				if(jQuery('#final_countdown_background_color').length)
				{
					
					background_opacity =percentageToHex(jQuery( "#final_countdown_background_opacity" ).val())
					backgroound_color=background_opacity+(jQuery('#final_countdown_background_color').val().substr(1));
					backgroound_color=signedIntBin2Dec(hex2bin(backgroound_color.toUpperCase()), 30)+"";
				}

				if(jQuery('#final_countdown_width').length)
					width=jQuery('#final_countdown_width').val();
					
				if(jQuery('#final_countdown_height').length)
					height=jQuery('#final_countdown_height').val();		
				
				/*if(event_name=="")
				{
					alert("Please enter event name");
					return;
				}*/

				var current_time=(new Date).getTime();
				var event_date_arr=event_date.split("/");
				var event_time_arr=event_time.split(":");
				var target_time=new Date(event_date_arr[2],(event_date_arr[1]-1),event_date_arr[0],event_time_arr[0],event_time_arr[1],0,0).getTime();
				
				var reqdata={
					   "Eventid": "",
					   "startTime": 0,
					   "targetTime": target_time,
					   "createdDate": current_time,
					   "eventName": event_name,
					   "countUp":count_up,
					   "timezone": timezone,
					   "recurring": 0,
					   "skin": {
					     "id": "1000",
					     "color": title_color,
					     "bgColor": backgroound_color,
					     "titleColor": title_color,
					     "borderColor":border_color,
					     "fontId": font_style
					   },
					   "shareType": "wordpress",
					   "lastUpdated": current_time,
					   "tags": [],
					   "_deleted": false
				   }

				var is_recurring=false;
				if(jQuery('#final_countdown_recurring').is(':checked')){
					is_recurring=true;
				}

				var recstr=new Array();
				if(is_recurring)
				{
					frequency =jQuery('#final_countdown_rfrequency').val();
					recstr.push("FREQ="+frequency);
					
					interval = jQuery('#final_countdown_rinterval').val();
					if(interval>1){
						recstr.push("INTERVAL="+interval);
					}

					if(frequency=="WEEKLY")
					{
						var repton=[]; 
						jQuery('input[name=final_countdown_rrepton]:checked').each(function(){
							repton.push(jQuery(this).val());
						});
						if(repton.length<=0)
						{
							var curdate = new Date();
							var weekday = new Array(7);
							weekday[0]=  "SU";
							weekday[1] = "MO";
							weekday[2] = "TU";
							weekday[3] = "WE";
							weekday[4] = "TH";
							weekday[5] = "FR";
							weekday[6] = "SA";
							repton.push(weekday[curdate.getDay()]);
						}
						recstr.push("WKST=SU;BYDAY="+repton.join(","));
					}
					endson = jQuery('input[name=final_countdown_endson]:checked').val();

					if(endson=="count")
					{
						var count=parseInt(jQuery('#final_countdown_count_input').val(),10);
						recstr.push("COUNT="+count)
					}
					else if(endson=="until")
					{
						var until=(jQuery('#final_countdown_until_input').val()).split("/");
						var untilstr =until[2]+until[1]+until[0]+"T000000Z";
						recstr.push("UNTIL="+untilstr);
					}
					
					reqdata.rrule=recstr.join(";");
				}

				jQuery('.final_countdown_spinner').css('visibility', 'visible');
				jQuery.post(
					    ajaxurl, 
					    {
					        'action': 'call_event_api',
					        'data':  reqdata
					    }, 
					    function(response){
					    	  jQuery('.final_countdown_spinner').css('visibility', 'hidden');
					   		   var response= JSON.parse(response);
						       if(response['status'])
						       {
						    	  	tagtext = '[final_countdown id="'+response['data']['eventId']+'" width="'+width+'" height="'+height+'"]';
					              	window.send_to_editor(tagtext);
					          		tb_remove();
						       }
						       else
						       {
							       alert(response['message']);
						       }
						     
					    }
					);
        }	
            </script>
	<?php 
	die;
	}
	
	/**
	 * Call event api.
	 *
	 * @since    1.0.0
	 */
	public function final_countdown_call_event_api() {
		
		$info = $_POST['data'];
		$message=array();
		$response = wp_remote_post(
				'https://origin.fncd.net/api/event',
				array(
						'method' => 'POST',
						'timeout' => 45,						
						'httpversion' => '1.0',						
						'headers' => array(
								'Content-Type' => 'application/json',								
						),
						'cookies' => array(),
						'body' => json_encode($info),
				)
		);
		
		if ( is_wp_error( $response ) ) {
			$error_message = $response->get_error_message();
			$message=array(
					'status'=>0,
					'message'=>"Something went wrong: $error_message",				
					'data'=>''
			);
		} else {
			
			if($response['response']['code']=="200")
			{
				$message=array(
						'status'=>1,
						'message'=>$response['response']['message'],
						'data'=>json_decode($response['body'],1)
				);
			}
			else
			{
				$message=array(
						'status'=>0,
						'message'=>$response['response']['message'],
						'data'=>''
				);
			}
		} 
		echo json_encode($message);
		die;
	}
}